Struct style::stylesheets::font_feature_values_rule::FFVDeclaration
[−]
[src]
pub struct FFVDeclaration<T> {
pub name: Atom,
pub value: T,
}A @font-feature-values block declaration.
It is <ident>: <integer>+.
This struct can take 3 value types.
- SingleValue is to keep just one unsigned integer value.
- PairValues is to keep one or two unsigned integer values.
- VectorValues is to keep a list of unsigned integer values.
Fields
name: Atom
An <ident> for declaration name.
value: T
An <integer>+ for declaration value.